import os
import pandas as pd
from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.keys import Keys

# ChromeDriver 경로 설정 (실제 경로로 수정)
chrome_driver_path = r'C:\tools\chromedriver\chromedriver.exe'

# 저장 경로 설정
save_path = r'\\DESKTOP-BQ3PFG6\data\economic_data'

# 디렉토리가 존재하지 않으면 생성
if not os.path.exists(save_path):
    os.makedirs(save_path)

# 크롬 옵션 설정
chrome_options = Options()
chrome_options.add_argument('--headless')
chrome_options.add_argument('--disable-gpu')
chrome_options.add_argument('--window-size=1920x1080')
chrome_options.add_argument('--disable-blink-features=AutomationControlled')
chrome_options.add_argument('--no-sandbox')
chrome_options.add_argument('--disable-dev-shm-usage')
chrome_options.add_argument('start-maximized')
chrome_options.add_argument('enable-automation')
chrome_options.add_argument('--disable-infobars')
chrome_options.add_argument('--disable-extensions')
chrome_options.add_argument('--disable-browser-side-navigation')
chrome_options.add_argument('--disable-features=VizDisplayCompositor')

# 사용자 에이전트 설정
user_agent = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36"
chrome_options.add_argument(f'user-agent={user_agent}')

# ChromeDriver 서비스 설정
chrome_service = Service(executable_path=chrome_driver_path)

# 웹 드라이버 설정
driver = webdriver.Chrome(service=chrome_service, options=chrome_options)

# 네이버 뉴스와 경제 페이지를 통한 데이터 수집 함수
def search_and_collect_data(search_term):
    driver.get('https://www.naver.com')
    data = []
    try:
        # 검색 입력 필드 찾기
        search_box = WebDriverWait(driver, 10).until(
            EC.presence_of_element_located((By.NAME, 'query'))
        )
        # 검색어 입력 및 엔터키 누르기
        search_box.send_keys(search_term)
        search_box.send_keys(Keys.RETURN)
        
        # 검색 결과 페이지 로딩 대기
        WebDriverWait(driver, 10).until(
            EC.presence_of_element_located((By.CLASS_NAME, 'list_news'))
        )

        # 검색 결과 테이블 찾기
        articles = driver.find_elements(By.CLASS_NAME, 'news_area')

        for article in articles:
            title = article.find_element(By.CLASS_NAME, 'news_tit').text
            source = article.find_element(By.CLASS_NAME, 'info_group').text
            link = article.find_element(By.CLASS_NAME, 'news_tit').get_attribute('href')
            data.append([title, source, link])
    except Exception as e:
        print(f"Error while fetching data for {search_term}: {e}")
    return data

# 검색어에 따른 데이터 수집
gdp_data = search_and_collect_data('GDP')
cpi_data = search_and_collect_data('물가상승률')
unemployment_data = search_and_collect_data('실업률')

# 드라이버 종료
driver.quit()

# 빈 데이터 필터링 및 데이터프레임 변환
if gdp_data:
    gdp_df = pd.DataFrame(gdp_data, columns=['Title', 'Source', 'Link'])
    gdp_df.to_csv(os.path.join(save_path, 'gdp_data.csv'), index=False)
    print(f"GDP data saved to {os.path.join(save_path, 'gdp_data.csv')}")
else:
    print("No GDP data collected.")

if cpi_data:
    cpi_df = pd.DataFrame(cpi_data, columns=['Title', 'Source', 'Link'])
    cpi_df.to_csv(os.path.join(save_path, 'cpi_data.csv'), index=False)
    print(f"CPI data saved to {os.path.join(save_path, 'cpi_data.csv')}")
else:
    print("No CPI data collected.")

if unemployment_data:
    unemployment_df = pd.DataFrame(unemployment_data, columns=['Title', 'Source', 'Link'])
    unemployment_df.to_csv(os.path.join(save_path, 'unemployment_data.csv'), index=False)
    print(f"Unemployment data saved to {os.path.join(save_path, 'unemployment_data.csv')}")
else:
    print("No Unemployment data collected.")
