import yfinance as yf
import numpy as np
import pandas as pd
from data_preprocessing import normalize_data
from model_training import update_lstm_model  # Correct import

def get_real_time_data(ticker, period='1d', interval='1m'):
    try:
        data = yf.download(ticker, period=period, interval=interval)
        return data
    except Exception as e:
        print(f"Error fetching data for {ticker}: {e}")
        return None

def create_dataset(dataset, time_step=1):
    X, Y = [], []
    for i in range(len(dataset) - time_step - 1):
        a = dataset[i:(i + time_step), 0]
        X.append(a)
        Y.append(dataset[i + time_step, 0])
    return np.array(X), np.array(Y)

def real_time_prediction(model, scaler, ticker, time_step=60):
    real_time_data = get_real_time_data(ticker)
    if real_time_data is None:
        return None
    real_time_data, _ = normalize_data(real_time_data)
    scaled_real_time_data = real_time_data['Close'].values.reshape(-1, 1)
    X_real_time, _ = create_dataset(scaled_real_time_data, time_step)
    X_real_time = X_real_time.reshape(X_real_time.shape[0], X_real_time.shape[1], 1)
    predictions = model.predict(X_real_time)
    predictions = scaler.inverse_transform(predictions)
    return predictions

def update_real_time_model(model, scaler, ticker, time_step=60):
    real_time_data = get_real_time_data(ticker)
    if real_time_data is None:
        return model
    real_time_data, _ = normalize_data(real_time_data)
    scaled_real_time_data = real_time_data['Close'].values.reshape(-1, 1)
    X_real_time, y_real_time = create_dataset(scaled_real_time_data, time_step)
    X_real_time = X_real_time.reshape(X_real_time.shape[0], X_real_time.shape[1], 1)
    model = update_lstm_model(pd.DataFrame(y_real_time), model, time_step)
    return model

if __name__ == '__main__':
    from data_collection import collect_stock_data
    from data_preprocessing import preprocess_data
    from model_training import train_model
    from config import *

    STOCK_TICKER = "AAPL"  # Define your stock ticker symbol here

    try:
        stock_data = collect_stock_data(STOCK_TICKER, START_DATE, END_DATE)
        (train_data, test_data), scaler = preprocess_data(stock_data, None, None, None)

        model = train_model(train_data['Close'])

        real_time_predictions = real_time_prediction(model, scaler, STOCK_TICKER)
        if real_time_predictions is not None:
            print(real_time_predictions)
        else:
            print("Failed to fetch real-time predictions.")
    except Exception as e:
        print(f"An error occurred: {e}")
