from skopt import BayesSearchCV
from skopt.space import Real, Integer
from tensorflow.keras.wrappers.scikit_learn import KerasClassifier
from tensorflow.keras.models import Sequential
from tensorflow.keras.layers import Dense
from tensorflow.keras.optimizers import Adam

def create_model(learning_rate=0.001, neurons=24):
    model = Sequential()
    model.add(Dense(neurons, input_dim=10, activation='relu'))  # input_dim should match the state size
    model.add(Dense(neurons, activation='relu'))
    model.add(Dense(3, activation='linear'))
    model.compile(loss='mse', optimizer=Adam(lr=learning_rate))
    return model

def tune_hyperparameters(X, y):
    model = KerasClassifier(build_fn=create_model, epochs=10, batch_size=10, verbose=0)
    param_grid = {
        'learning_rate': Real(1e-4, 1e-2, prior='log-uniform'),
        'neurons': Integer(16, 128)
    }
    search = BayesSearchCV(estimator=model, search_spaces=param_grid, n_iter=10, cv=3, verbose=1)
    search.fit(X, y)
    return search.best_params_
