import numpy as np
from tensorflow.keras.models import Sequential
from tensorflow.keras.layers import LSTM, Dense

def create_dataset(dataset, time_step=1):
    X, Y = [], []
    for i in range(len(dataset) - time_step - 1):
        a = dataset[i:(i + time_step), 0]
        X.append(a)
        Y.append(dataset[i + time_step, 0])
    return np.array(X), np.array(Y)

def build_lstm_model(input_shape):
    model = Sequential()
    model.add(LSTM(50, return_sequences=True, input_shape=input_shape))
    model.add(LSTM(50, return_sequences=False))
    model.add(Dense(25))
    model.add(Dense(1))
    model.compile(optimizer='adam', loss='mean_squared_error')
    return model

def train_lstm_model(train_data, time_step=60):
    X_train, y_train = create_dataset(train_data.values, time_step)
    X_train = X_train.reshape(X_train.shape[0], X_train.shape[1], 1)
    model = build_lstm_model((time_step, 1))
    model.fit(X_train, y_train, epochs=10, batch_size=32, verbose=1)
    return model

def update_lstm_model(train_data, model, time_step=60):
    X_train, y_train = create_dataset(train_data.values, time_step)
    X_train = X_train.reshape(X_train.shape[0], X_train.shape[1], 1)
    model.fit(X_train, y_train, epochs=5, batch_size=32, verbose=1)
    return model
